# Livermark

[![Build](https://img.shields.io/github/workflow/status/frictionlessdata/livemark/general/main)](https://github.com/frictionlessdata/livemark/actions)
[![Coverage](https://img.shields.io/codecov/c/github/frictionlessdata/livemark/main)](https://codecov.io/gh/frictionlessdata/livemark)
[![Registry](https://img.shields.io/pypi/v/livemark.svg)](https://pypi.python.org/pypi/livemark)
[![Codebase](https://img.shields.io/badge/codebase-github-brightgreen)](https://github.com/frictionlessdata/livemark)
[![Support](https://img.shields.io/badge/support-discord-brightgreen)](https://discordapp.com/invite/Sewv6av)

> This software is in the early stages and is not well-tested

Livemark is a Python static site generator that extends Markdown with interactive charts, tables, scripts, and other features.

## Purpose

- **Improved writing experience**: Now your Markdown data articles can include interactive charts, tables, a live development server, and much more.
- **Static site generator**: Livemark only operates with static files - it creates an HTML file from your Mardown file.

## Features

- Open Source (MIT)
- Full Markdown compatibility
- Markdown extensions such as tables and charts
- Straight-forward command-line interface
- Live development server

## Example

[![Example](assets/example.png)](https://livemark.frictionlessdata.io)

## Documentation

Please visit our documentation portal:
- https://livemark.frictionlessdata.io
